package com.meas.system.controller;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Enumeration;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipFile;
import java.util.zip.ZipInputStream;

import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.meas.common.annotation.Log;
import com.meas.common.config.RuoYiConfig;
import com.meas.common.core.controller.BaseController;
import com.meas.common.core.domain.AjaxResult;
import com.meas.common.core.domain.entity.SysDept;
import com.meas.common.enums.BusinessType;
import com.meas.system.domain.MeasEnvData;
import com.meas.system.service.IMeasEnvDataService;
import com.meas.common.utils.poi.ExcelUtil;
import com.meas.common.core.page.TableDataInfo;

/**
 * 测量环境数据Controller
 *
 * @author wgk
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/meas/envData")
public class MeasEnvDataController extends BaseController {
    @Autowired
    private IMeasEnvDataService measEnvDataService;

    /**
     * 查询测量环境数据列表
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:list')")
    @GetMapping("/list")
    public TableDataInfo list(MeasEnvData measEnvData) {
        startPage();
        List<MeasEnvData> list = measEnvDataService.selectMeasEnvDataList(measEnvData);
        return getDataTable(list);
    }

    /**
     * 导出测量环境数据列表
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:export')")
    @Log(title = "测量环境数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MeasEnvData measEnvData) {
        List<MeasEnvData> list = measEnvDataService.selectMeasEnvDataList(measEnvData);
        ExcelUtil<MeasEnvData> util = new ExcelUtil<MeasEnvData>(MeasEnvData.class);
        util.exportExcel(response, list, "测量环境数据数据");
    }

    /**
     * 获取测量环境数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(measEnvDataService.selectMeasEnvDataById(id));
    }

    /**
     * 新增测量环境数据
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:add')")
    @Log(title = "测量环境数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MeasEnvData measEnvData) {
        MeasEnvData returnValue = measEnvDataService.insertMeasEnvData(measEnvData);
        if(returnValue == null){
            return error();
        } else {
            return success(returnValue);
        }
    }

    /**
     * 修改测量环境数据
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:edit')")
    @Log(title = "测量环境数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MeasEnvData measEnvData) {
        return toAjax(measEnvDataService.updateMeasEnvData(measEnvData));
    }

    /**
     * 删除测量环境数据
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:remove')")
    @Log(title = "测量环境数据", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(measEnvDataService.deleteMeasEnvDataByIds(ids));
    }

    /**
     * 查询测量环境数据树结构信息
     */
    @PreAuthorize("@ss.hasPermi('meas:envData:list')")
    @GetMapping("/measEnvDataTree")
    public AjaxResult measEnvDataTree(String measurementBatch) {
        return success(measEnvDataService.selectMeasEnvDataTreeList(measurementBatch));
    }
    
//    public static void main(String[] args) {
//    	readZip("/profile/upload/2024/11/05/1_20241105133400A002.zip");
//	}

    /**
     * 获取zip包中文件url
     */
    @GetMapping("/readZip")
    public List<String> readZip(String zipUrl) {
    	String zipFilePath = RuoYiConfig.getProfile()+zipUrl.replace("/profile", ""); // 替换为你的zip文件路径
        System.out.println("zipFilePath: " + zipFilePath);
		String destDirectory = zipFilePath.split(".zip")[0];
        System.out.println("destDirectory: " + destDirectory);
		File destDir = new File(destDirectory);
	    deleteFolder(destDir);
	    if (!destDir.exists()) {
	        destDir.mkdir();
	    }
	    try (ZipFile zipFile = new ZipFile(zipFilePath,Charset.forName("GBK"))) {
	        
	        Enumeration<? extends ZipEntry> entries = zipFile.entries();
	        while (entries.hasMoreElements()) {
	            ZipEntry entry = entries.nextElement();
	            String filePath = destDirectory + File.separator + entry.getName();
	            if (!entry.isDirectory()) {
	                extractFile(zipFile, entry, filePath);
	            } else {
	                File dir = new File(filePath);
	                dir.mkdir();
	            }
	        }
	    } catch (ZipException e) {
	        System.err.println("Not a valid ZIP file.");
	    } catch (IOException e) {
	        System.err.println("I/O error.");
	    }
	    
		// 创建文件夹对象
	    File folder = new File(destDirectory);
	
	    // 获取文件夹中的文件列表
	    File[] listOfFiles = folder.listFiles();
	
	    List<String> list = new ArrayList<String>();
	    // 确保文件数组不为空
	    if (listOfFiles != null) {
	        // 对文件数组进行排序
	        Arrays.sort(listOfFiles);
	
	        // 遍历并打印文件名
	        for (File file : listOfFiles) {
	            if (file.isFile()) {
	            	list.add(zipUrl.split(".zip")[0]+"/"+file.getName());
	                System.out.println("File: " + zipUrl.split(".zip")[0]+"/"+file.getName());
	            }
	        }
	    }
		return list;
    }
    
    public static void deleteFolder(File folder) {
        if (folder.isDirectory()) {
            File[] files = folder.listFiles();
            if (files != null) {
                for (File file : files) {
                    deleteFolder(file);
                }
            }
        }
        folder.delete();
    }
    
    private static void extractFile(ZipFile zipFile, ZipEntry entry, String filePath) throws IOException {
        try (BufferedOutputStream bos = new BufferedOutputStream(new FileOutputStream(filePath))) {
            byte[] buffer = new byte[1024];
            int length;
            InputStream inputStream = zipFile.getInputStream(entry);
            while ((length = inputStream.read(buffer)) > 0) {
                bos.write(buffer, 0, length);
            }
            inputStream.close();
        }
    }

    /**
     * 获取数据对比列表
     */
    @GetMapping("/contrastDataList")
    public List<Map<String, String>> contrastDataList(Long[] batchIds,Integer contrastType) {
		return measEnvDataService.selectContrastDataList(batchIds, contrastType);
    }
}
