package com.meas.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.meas.common.annotation.Log;
import com.meas.common.core.controller.BaseController;
import com.meas.common.core.domain.AjaxResult;
import com.meas.common.enums.BusinessType;
import com.meas.system.domain.MeasSpectralRadiationRadiance;
import com.meas.system.service.IMeasSpectralRadiationRadianceService;
import com.meas.common.utils.poi.ExcelUtil;
import com.meas.common.core.page.TableDataInfo;

/**
 * 光谱辐射-辐射亮度Controller
 *
 * @author Allen
 * @date 2025-07-08
 */
@RestController
@RequestMapping("/meas/radiance")
public class MeasSpectralRadiationRadianceController extends BaseController {
    @Autowired
    private IMeasSpectralRadiationRadianceService measSpectralRadiationRadianceService;

/**
 * 查询光谱辐射-辐射亮度列表
 */
@PreAuthorize("@ss.hasPermi('system:radiance:list')")
@GetMapping("/list")
    public TableDataInfo list(MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        startPage();
        List<MeasSpectralRadiationRadiance> list = measSpectralRadiationRadianceService.selectMeasSpectralRadiationRadianceList(measSpectralRadiationRadiance);
        return getDataTable(list);
    }

    /**
     * 导出光谱辐射-辐射亮度列表
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:export')")
    @Log(title = "光谱辐射-辐射亮度", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        List<MeasSpectralRadiationRadiance> list = measSpectralRadiationRadianceService.selectMeasSpectralRadiationRadianceList(measSpectralRadiationRadiance);
        ExcelUtil<MeasSpectralRadiationRadiance> util = new ExcelUtil<MeasSpectralRadiationRadiance>(MeasSpectralRadiationRadiance. class);
        util.exportExcel(response, list, "光谱辐射-辐射亮度数据");
    }

    /**
     * 获取光谱辐射-辐射亮度详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(measSpectralRadiationRadianceService.selectMeasSpectralRadiationRadianceById(id));
    }

    /**
     * 新增光谱辐射-辐射亮度
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:add')")
    @Log(title = "光谱辐射-辐射亮度", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        return toAjax(measSpectralRadiationRadianceService.insertMeasSpectralRadiationRadiance(measSpectralRadiationRadiance));
    }

    /**
     * 修改光谱辐射-辐射亮度
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:edit')")
    @Log(title = "光谱辐射-辐射亮度", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        return toAjax(measSpectralRadiationRadianceService.updateMeasSpectralRadiationRadiance(measSpectralRadiationRadiance));
    }

    /**
     * 删除光谱辐射-辐射亮度
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:remove')")
    @Log(title = "光谱辐射-辐射亮度", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(measSpectralRadiationRadianceService.deleteMeasSpectralRadiationRadianceByIds(ids));
    }

    /**
     * 通过测量批次、型号、光阑、标定温度获取光谱辐射-辐射亮度详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:radiance:query')")
    @PostMapping(value = "/getInfoByCondition")
    public AjaxResult getInfoByCondition(@RequestBody MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        return success(measSpectralRadiationRadianceService.getInfoByCondition(measSpectralRadiationRadiance));
    }
}
