package com.meas.system.domain;

import com.meas.common.annotation.Excel;
import com.meas.common.core.domain.BaseEntity;

import java.math.BigDecimal;

/**
 * 光谱辐射对象 meas_spectral_radiation
 *
 * @author wgk
 * @date 2024-06-13
 */
public class MeasSpectralRadiation extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 编号
     */
    private Long id;

    /**
     * 测量环境id
     */
    @Excel(name = "测量环境id")
    private Long measurementBatchId;

    /**
     * 发动机型号
     */
    private String engineModel;

    /**
     * 几何模型文件
     */
    private String geometryFiles;

    /**
     * 几何模型图片
     */
    private String geometryImage;

    /**
     * 测量批次
     */
    private String measurementBatch;

    /**
     * 发动机状态
     */
    private String engineStatus;

    /**
     * 角度
     */
    private String angle;

    /**
     * 型号
     */
    @Excel(name = "型号")
    private String model;

    /**
     * 镜头视场角
     */
    @Excel(name = "镜头视场角")
    private BigDecimal lensFView;

    /**
     * 增益
     */
    @Excel(name = "增益")
    private double gain;

    private Long radianceId;

    /**
     * 背景数据
     */
    @Excel(name = "背景数据")
    private String backgroundData;

    /**
     * 标定温度
     */
    @Excel(name = "标定温度")
    private String calTemp;

    /**
     * 标定曲线
     */
    @Excel(name = "3~5μm 标定曲线")
    private String calCurve;
    /**
     * 标定曲线
     */
    @Excel(name = "8~14μm 标定曲线")
    private String calCurve2;

    /**
     * 原始数据
     */
    @Excel(name = "原始数据")
    private String rawData;

    /**
     * 辐射亮度（3~5μm）
     */
    @Excel(name = "辐射亮度", readConverterExp = "3=~5μm")
    private String radiance1;

    /**
     * 辐射亮度（8~14μm）
     */
    @Excel(name = "辐射亮度", readConverterExp = "8=~14μm")
    private String radiance2;

    /** 标定温度 */
    @Excel(name = "标定温度")
    private String calTempEk;

    /** 原始目标(3~5μm) */
    @Excel(name = "原始目标(3~5μm)", readConverterExp = "3=~5μm")
    private String rawTarget1;

    /** 原始目标(8~14μm) */
    @Excel(name = "原始目标(8~14μm)", readConverterExp = "8=~14μm")
    private String rawTarget2;

    /** 原始背景(3~5μm) */
    @Excel(name = "原始背景(3~5μm)", readConverterExp = "3=~5μm")
    private String rawBackground1;

    /** 原始背景(8~14μm) */
    @Excel(name = "原始背景(8~14μm)", readConverterExp = "8=~14μm")
    private String rawBackground2;

    /** 处理后目标(3~5μm) */
    @Excel(name = "处理后目标(3~5μm)", readConverterExp = "3=~5μm")
    private String tackleTarget1;

    /** 处理后目标(8~14μm) */
    @Excel(name = "处理后目标(8~14μm)", readConverterExp = "8=~14μm")
    private String tackleTarget2;

    /** 处理后背景(3~5μm) */
    @Excel(name = "处理后背景(3~5μm)", readConverterExp = "3=~5μm")
    private String tackleBackground1;

    /** 处理后背景(8~14μm) */
    @Excel(name = "处理后背景(8~14μm)", readConverterExp = "8=~14μm")
    private String tackleBackground2;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getMeasurementBatchId() {
        return measurementBatchId;
    }

    public void setMeasurementBatchId(Long measurementBatchId) {
        this.measurementBatchId = measurementBatchId;
    }

    public String getEngineModel() {
        return engineModel;
    }

    public void setEngineModel(String engineModel) {
        this.engineModel = engineModel;
    }

    public String getGeometryFiles() {
        return geometryFiles;
    }

    public void setGeometryFiles(String geometryFiles) {
        this.geometryFiles = geometryFiles;
    }

    public String getGeometryImage() {
        return geometryImage;
    }

    public void setGeometryImage(String geometryImage) {
        this.geometryImage = geometryImage;
    }

    public String getMeasurementBatch() {
        return measurementBatch;
    }

    public void setMeasurementBatch(String measurementBatch) {
        this.measurementBatch = measurementBatch;
    }

    public String getEngineStatus() {
        return engineStatus;
    }

    public void setEngineStatus(String engineStatus) {
        this.engineStatus = engineStatus;
    }

    public String getAngle() {
        return angle;
    }

    public void setAngle(String angle) {
        this.angle = angle;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public BigDecimal getLensFView() {
        return lensFView;
    }

    public void setLensFView(BigDecimal lensFView) {
        this.lensFView = lensFView;
    }

    public double getGain() {
        return gain;
    }

    public void setGain(double gain) {
        this.gain = gain;
    }

    public Long getRadianceId() {
        return radianceId;
    }

    public void setRadianceId(Long radianceId) {
        this.radianceId = radianceId;
    }

    public String getBackgroundData() {
        return backgroundData;
    }

    public void setBackgroundData(String backgroundData) {
        this.backgroundData = backgroundData;
    }

    public String getCalTemp() {
        return calTemp;
    }

    public void setCalTemp(String calTemp) {
        this.calTemp = calTemp;
    }

    public String getCalCurve() {
        return calCurve;
    }

    public void setCalCurve(String calCurve) {
        this.calCurve = calCurve;
    }

    public String getCalCurve2() {
        return calCurve2;
    }

    public void setCalCurve2(String calCurve2) {
        this.calCurve2 = calCurve2;
    }

    public String getRawData() {
        return rawData;
    }

    public void setRawData(String rawData) {
        this.rawData = rawData;
    }

    public String getRadiance1() {
        return radiance1;
    }

    public void setRadiance1(String radiance1) {
        this.radiance1 = radiance1;
    }

    public String getRadiance2() {
        return radiance2;
    }

    public void setRadiance2(String radiance2) {
        this.radiance2 = radiance2;
    }

    public String getCalTempEk() {
        return calTempEk;
    }

    public void setCalTempEk(String calTempEk) {
        this.calTempEk = calTempEk;
    }

    public String getRawTarget1() {
        return rawTarget1;
    }

    public void setRawTarget1(String rawTarget1) {
        this.rawTarget1 = rawTarget1;
    }

    public String getRawTarget2() {
        return rawTarget2;
    }

    public void setRawTarget2(String rawTarget2) {
        this.rawTarget2 = rawTarget2;
    }

    public String getRawBackground1() {
        return rawBackground1;
    }

    public void setRawBackground1(String rawBackground1) {
        this.rawBackground1 = rawBackground1;
    }

    public String getRawBackground2() {
        return rawBackground2;
    }

    public void setRawBackground2(String rawBackground2) {
        this.rawBackground2 = rawBackground2;
    }

    public String getTackleTarget1() {
        return tackleTarget1;
    }

    public void setTackleTarget1(String tackleTarget1) {
        this.tackleTarget1 = tackleTarget1;
    }

    public String getTackleTarget2() {
        return tackleTarget2;
    }

    public void setTackleTarget2(String tackleTarget2) {
        this.tackleTarget2 = tackleTarget2;
    }

    public String getTackleBackground1() {
        return tackleBackground1;
    }

    public void setTackleBackground1(String tackleBackground1) {
        this.tackleBackground1 = tackleBackground1;
    }

    public String getTackleBackground2() {
        return tackleBackground2;
    }

    public void setTackleBackground2(String tackleBackground2) {
        this.tackleBackground2 = tackleBackground2;
    }

    @Override
    public String toString() {
        return "MeasSpectralRadiation{" +
                "id=" + id +
                ", measurementBatchId=" + measurementBatchId +
                ", engineModel='" + engineModel + '\'' +
                ", geometryFiles='" + geometryFiles + '\'' +
                ", geometryImage='" + geometryImage + '\'' +
                ", measurementBatch='" + measurementBatch + '\'' +
                ", engineStatus='" + engineStatus + '\'' +
                ", angle='" + angle + '\'' +
                ", model='" + model + '\'' +
                ", lensFView=" + lensFView +
                ", gain=" + gain +
                ", radianceId=" + radianceId +
                ", backgroundData='" + backgroundData + '\'' +
                ", calTemp='" + calTemp + '\'' +
                ", calCurve='" + calCurve + '\'' +
                ", calCurve2='" + calCurve2 + '\'' +
                ", rawData='" + rawData + '\'' +
                ", radiance1='" + radiance1 + '\'' +
                ", radiance2='" + radiance2 + '\'' +
                ", calTempEk='" + calTempEk + '\'' +
                ", rawTarget1='" + rawTarget1 + '\'' +
                ", rawTarget2='" + rawTarget2 + '\'' +
                ", rawBackground1='" + rawBackground1 + '\'' +
                ", rawBackground2='" + rawBackground2 + '\'' +
                ", tackleTarget1='" + tackleTarget1 + '\'' +
                ", tackleTarget2='" + tackleTarget2 + '\'' +
                ", tackleBackground1='" + tackleBackground1 + '\'' +
                ", tackleBackground2='" + tackleBackground2 + '\'' +
                '}';
    }
}
