package com.meas.system.service;

import java.util.List;
import java.util.Map;

import com.meas.common.core.domain.TreeSelect;
import com.meas.system.domain.MeasEnvData;

/**
 * 测量环境数据Service接口
 *
 * @author wgk
 * @date 2024-06-13
 */
public interface IMeasEnvDataService {
    /**
     * 查询测量环境数据
     *
     * @param id 测量环境数据主键
     * @return 测量环境数据
     */
    public MeasEnvData selectMeasEnvDataById(Long id);

    /**
     * 查询测量环境数据列表
     *
     * @param measEnvData 测量环境数据
     * @return 测量环境数据集合
     */
    public List<MeasEnvData> selectMeasEnvDataList(MeasEnvData measEnvData);

    /**
     * 新增测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    public MeasEnvData insertMeasEnvData(MeasEnvData measEnvData);

    /**
     * 修改测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    public int updateMeasEnvData(MeasEnvData measEnvData);

    /**
     * 批量删除测量环境数据
     *
     * @param ids 需要删除的测量环境数据主键集合
     * @return 结果
     */
    public int deleteMeasEnvDataByIds(Long[] ids);

    /**
     * 删除测量环境数据信息
     *
     * @param id 测量环境数据主键
     * @return 结果
     */
    public int deleteMeasEnvDataById(Long id);

    /**
     * 查询测量环境数据树结构信息
     *
     * @return 测量环境数据树信息集合
     */
    public List<TreeSelect> selectMeasEnvDataTreeList(String measurementBatch);


    /**
     * 获取数据对比列表
     *
     */
    public List<Map<String, String>> selectContrastDataList(Long[] batchIds,Integer contrastType);
}
