package com.meas.system.service.impl;

import com.meas.common.core.domain.TreeSelect;
import com.meas.common.utils.DateUtils;
import com.meas.system.domain.MeasAngle;
import com.meas.system.domain.MeasDataResults;
import com.meas.system.domain.MeasEnvData;
import com.meas.system.domain.MeasSpectralRadiation;
import com.meas.system.domain.MeasStatus;
import com.meas.system.domain.MeasTransmissionRate;
import com.meas.system.mapper.MeasAngleMapper;
import com.meas.system.mapper.MeasDataResultsMapper;
import com.meas.system.mapper.MeasEnvDataMapper;
import com.meas.system.mapper.MeasSpectralRadiationMapper;
import com.meas.system.mapper.MeasStatusMapper;
import com.meas.system.mapper.MeasTransmissionRateMapper;
import com.meas.system.service.IMeasEnvDataService;
import com.meas.system.service.ISysConfigService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 测量环境数据Service业务层处理
 *
 * @author wgk
 * @date 2024-06-13
 */
@Service
public class MeasEnvDataServiceImpl implements IMeasEnvDataService {
    @Autowired
    private MeasEnvDataMapper measEnvDataMapper;
    @Autowired
    private ISysConfigService configService;
    @Autowired
    private MeasSpectralRadiationMapper measSpectralRadiationMapper;
    @Autowired
    private MeasDataResultsMapper measDataResultsMapper;
    @Autowired
    private MeasTransmissionRateMapper measTransmissionRateMapper;
    @Autowired
    private MeasStatusMapper measStatusMapper;
    @Autowired
    private MeasAngleMapper measAngleMapper;

    /**
     * 查询测量环境数据
     *
     * @param id 测量环境数据主键
     * @return 测量环境数据
     */
    @Override
    public MeasEnvData selectMeasEnvDataById(Long id) {
        return measEnvDataMapper.selectMeasEnvDataById(id);
    }

    /**
     * 查询测量环境数据列表
     *
     * @param measEnvData 测量环境数据
     * @return 测量环境数据
     */
    @Override
    public List<MeasEnvData> selectMeasEnvDataList(MeasEnvData measEnvData) {
        return measEnvDataMapper.selectMeasEnvDataList(measEnvData);
    }

    /**
     * 新增测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    @Override
    public MeasEnvData insertMeasEnvData(MeasEnvData measEnvData) {
        measEnvData.setCreateTime(DateUtils.getNowDate());
        MeasStatus measStatus = new MeasStatus();
        measStatus.setStatus(measEnvData.getEngineStatus());
        List<MeasStatus> list = measStatusMapper.selectMeasStatusList(measStatus);
        if(list.size() > 0) {
        	measEnvData.setEngineStatusId(list.get(0).getId());
        }
        MeasAngle measAngle = new MeasAngle();
        measAngle.setAngle(Long.valueOf(measEnvData.getAngle()));
        List<MeasAngle> list1 = measAngleMapper.selectMeasAngleList(measAngle);
        if(list1.size() > 0) {
        	measEnvData.setAngleId(list1.get(0).getId());
        }
        int i = measEnvDataMapper.insertMeasEnvData(measEnvData);
        if (i > 0) {
            return measEnvData;
        } else {
            return null;
        }
    }

    /**
     * 修改测量环境数据
     *
     * @param measEnvData 测量环境数据
     * @return 结果
     */
    @Override
    public int updateMeasEnvData(MeasEnvData measEnvData) {
        measEnvData.setUpdateTime(DateUtils.getNowDate());
        MeasStatus measStatus = new MeasStatus();
        measStatus.setStatus(measEnvData.getEngineStatus());
        List<MeasStatus> list = measStatusMapper.selectMeasStatusList(measStatus);
        if(list.size() > 0) {
        	measEnvData.setEngineStatusId(list.get(0).getId());
        }
        MeasAngle measAngle = new MeasAngle();
        measAngle.setAngle(Long.valueOf(measEnvData.getAngle()));
        List<MeasAngle> list1 = measAngleMapper.selectMeasAngleList(measAngle);
        if(list1.size() > 0) {
        	measEnvData.setAngleId(list1.get(0).getId());
        }
        return measEnvDataMapper.updateMeasEnvData(measEnvData);
    }

    /**
     * 批量删除测量环境数据
     *
     * @param ids 需要删除的测量环境数据主键
     * @return 结果
     */
    @Override
    public int deleteMeasEnvDataByIds(Long[] ids) {
        return measEnvDataMapper.deleteMeasEnvDataByIds(ids);
    }

    /**
     * 删除测量环境数据信息
     *
     * @param id 测量环境数据主键
     * @return 结果
     */
    @Override
    public int deleteMeasEnvDataById(Long id) {
        return measEnvDataMapper.deleteMeasEnvDataById(id);
    }

    /**
     * 查询测量环境数据树结构信息
     *
     * @return 测量环境数据树信息集合
     */
    public List<TreeSelect> selectMeasEnvDataTreeList(String measurementBatch){
        String pageSize = configService.selectConfigByKey("meas_batch_pageSize");
    	List<MeasEnvData> list1 = measEnvDataMapper.selectMeasurementBatchTree(measurementBatch,Integer.valueOf(pageSize));
    	List<TreeSelect> treeList1 = new ArrayList<TreeSelect>();
    	for (MeasEnvData measEnvData1 : list1) {
    		TreeSelect treeSelect1 = new TreeSelect();
    		treeSelect1.setId(measEnvData1.getMeasurementBatchId());
    		treeSelect1.setLabel(measEnvData1.getMeasurementBatch());
    		treeSelect1.setLevle(1);
    		treeSelect1.setParentId("0");
        	List<MeasEnvData> list2 = measEnvDataMapper.selectEngineStatusTree(measEnvData1.getMeasurementBatchId());
        	List<TreeSelect> treeList2 = new ArrayList<TreeSelect>();
        	for (MeasEnvData measEnvData2 : list2) {
        		TreeSelect treeSelect2 = new TreeSelect();
        		treeSelect2.setId(measEnvData2.getEngineStatusId());
        		treeSelect2.setLabel(measEnvData2.getEngineStatus());
        		treeSelect2.setLevle(2);
        		treeSelect2.setParentId(measEnvData1.getMeasurementBatchId().toString());
            	List<MeasEnvData> list3 = measEnvDataMapper.selectAngleTree(measEnvData1.getMeasurementBatchId(),measEnvData2.getEngineStatusId());
            	List<TreeSelect> treeList3 = new ArrayList<TreeSelect>();
            	for (MeasEnvData measEnvData3 : list3) {
            		TreeSelect treeSelect3 = new TreeSelect();
            		treeSelect3.setId(measEnvData3.getAngleId());
            		treeSelect3.setLabel(measEnvData3.getAngle());
            		treeSelect3.setLevle(3);
            		treeSelect3.setParentId(measEnvData1.getMeasurementBatchId().toString()+","+measEnvData2.getEngineStatusId());
            		treeList3.add(treeSelect3);
            	}
            	treeSelect2.setChildren(treeList3);
        		treeList2.add(treeSelect2);
        	}
        	treeSelect1.setChildren(treeList2);
    		treeList1.add(treeSelect1);
		}
		return treeList1;
    }

    /**
     * 获取数据对比列表
     *
     */
    public List<Map<String, String>> selectContrastDataList(Long[] batchIds,Integer contrastType){
    	List<Map<String, String>> contrastList = new ArrayList<Map<String, String>>();
    	if(contrastType == 1 || contrastType == 2) {
    		List<MeasSpectralRadiation> list = measSpectralRadiationMapper.selectContrastDataList(batchIds);
    		for (MeasSpectralRadiation measSpectralRadiation : list) {
    	    	Map<String, String> map = new HashMap<String, String>();
    			if(measSpectralRadiation != null) {
    				if(contrastType == 1 && measSpectralRadiation.getTackleTarget1() != null && !measSpectralRadiation.getTackleTarget1().equals("")) {
    					map.put("name", measSpectralRadiation.getMeasurementBatch()+"-"+measSpectralRadiation.getEngineStatus()+"-"+measSpectralRadiation.getAngle());
    					map.put("url", measSpectralRadiation.getTackleTarget1());
    					contrastList.add(map);
    				}else if(contrastType == 2 && measSpectralRadiation.getTackleTarget2() != null && !measSpectralRadiation.getTackleTarget2().equals("")) {
    					map.put("name", measSpectralRadiation.getMeasurementBatch()+"-"+measSpectralRadiation.getEngineStatus()+"-"+measSpectralRadiation.getAngle());
    					map.put("url", measSpectralRadiation.getTackleTarget2());
    					contrastList.add(map);
    				}
    			}
			}
    	}else if(contrastType == 3 || contrastType == 4) {
    		List<MeasDataResults> list = measDataResultsMapper.selectContrastDataList(batchIds);
    		for (MeasDataResults measDataResults : list) {
    	    	Map<String, String> map = new HashMap<String, String>();
    			if(measDataResults != null) {
    				if(contrastType == 3 && measDataResults.getSpecIrr1() != null && !measDataResults.getSpecIrr1().equals("")) {
    					map.put("name", measDataResults.getMeasurementBatch()+"-"+measDataResults.getEngineStatus()+"-"+measDataResults.getAngle());
    					map.put("url", measDataResults.getSpecIrr1());
    					contrastList.add(map);
    				}else if(contrastType == 4 && measDataResults.getSpecIrr2() != null && !measDataResults.getSpecIrr2().equals("")) {
    					map.put("name", measDataResults.getMeasurementBatch()+"-"+measDataResults.getEngineStatus()+"-"+measDataResults.getAngle());
    					map.put("url", measDataResults.getSpecIrr2());
    					contrastList.add(map);
    				}
    			}
			}
    	}else if(contrastType == 5 || contrastType == 6) {
    		List<MeasTransmissionRate> list = measTransmissionRateMapper.selectContrastDataList(batchIds);
    		for (MeasTransmissionRate measTransmissionRate : list) {
    	    	Map<String, String> map = new HashMap<String, String>();
    			if(measTransmissionRate != null) {
    				if(contrastType == 5 && measTransmissionRate.getCurve1() != null && !measTransmissionRate.getCurve1().equals("")) {
    					map.put("name", measTransmissionRate.getMeasurementBatch()+"-"+measTransmissionRate.getEngineStatus()+"-"+measTransmissionRate.getAngle());
    					map.put("url", measTransmissionRate.getCurve1());
    					contrastList.add(map);
    				}else if(contrastType == 6 && measTransmissionRate.getCurve2() != null && !measTransmissionRate.getCurve2().equals("")) {
    					map.put("name", measTransmissionRate.getMeasurementBatch()+"-"+measTransmissionRate.getEngineStatus()+"-"+measTransmissionRate.getAngle());
    					map.put("url", measTransmissionRate.getCurve2());
    					contrastList.add(map);
    				}
    			}
			}
    	}
    	return contrastList;
    }
}
