package com.meas.system.service.impl;

import java.util.List;
        import com.meas.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.meas.system.mapper.MeasSpectralRadiationRadianceMapper;
import com.meas.system.domain.MeasSpectralRadiationRadiance;
import com.meas.system.service.IMeasSpectralRadiationRadianceService;

/**
 * 光谱辐射-辐射亮度Service业务层处理
 *
 * @author Allen
 * @date 2025-07-08
 */
@Service
public class MeasSpectralRadiationRadianceServiceImpl implements IMeasSpectralRadiationRadianceService {
    @Autowired
    private MeasSpectralRadiationRadianceMapper measSpectralRadiationRadianceMapper;

    /**
     * 查询光谱辐射-辐射亮度
     *
     * @param id 光谱辐射-辐射亮度主键
     * @return 光谱辐射-辐射亮度
     */
    @Override
    public MeasSpectralRadiationRadiance selectMeasSpectralRadiationRadianceById(Long id) {
        return measSpectralRadiationRadianceMapper.selectMeasSpectralRadiationRadianceById(id);
    }

    /**
     * 查询光谱辐射-辐射亮度列表
     *
     * @param measSpectralRadiationRadiance 光谱辐射-辐射亮度
     * @return 光谱辐射-辐射亮度
     */
    @Override
    public List<MeasSpectralRadiationRadiance> selectMeasSpectralRadiationRadianceList(MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        return measSpectralRadiationRadianceMapper.selectMeasSpectralRadiationRadianceList(measSpectralRadiationRadiance);
    }

    /**
     * 新增光谱辐射-辐射亮度
     *
     * @param measSpectralRadiationRadiance 光谱辐射-辐射亮度
     * @return 结果
     */
    @Override
    public int insertMeasSpectralRadiationRadiance(MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
                measSpectralRadiationRadiance.setCreateTime(DateUtils.getNowDate());
            return measSpectralRadiationRadianceMapper.insertMeasSpectralRadiationRadiance(measSpectralRadiationRadiance);
    }

    /**
     * 修改光谱辐射-辐射亮度
     *
     * @param measSpectralRadiationRadiance 光谱辐射-辐射亮度
     * @return 结果
     */
    @Override
    public int updateMeasSpectralRadiationRadiance(MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
                measSpectralRadiationRadiance.setUpdateTime(DateUtils.getNowDate());
        return measSpectralRadiationRadianceMapper.updateMeasSpectralRadiationRadiance(measSpectralRadiationRadiance);
    }

    /**
     * 批量删除光谱辐射-辐射亮度
     *
     * @param ids 需要删除的光谱辐射-辐射亮度主键
     * @return 结果
     */
    @Override
    public int deleteMeasSpectralRadiationRadianceByIds(Long[] ids) {
        return measSpectralRadiationRadianceMapper.deleteMeasSpectralRadiationRadianceByIds(ids);
    }

    /**
     * 删除光谱辐射-辐射亮度信息
     *
     * @param id 光谱辐射-辐射亮度主键
     * @return 结果
     */
    @Override
    public int deleteMeasSpectralRadiationRadianceById(Long id) {
        return measSpectralRadiationRadianceMapper.deleteMeasSpectralRadiationRadianceById(id);
    }

    @Override
    public MeasSpectralRadiationRadiance getInfoByCondition(MeasSpectralRadiationRadiance measSpectralRadiationRadiance) {
        return measSpectralRadiationRadianceMapper.getInfoByCondition(measSpectralRadiationRadiance);
    }
}
